package com.ruoyi.system.controller;

import java.util.List;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.NavInfo;
import com.ruoyi.system.service.INavInfoService;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.common.core.domain.Ztree;

/**
 * 中关村导航管理Controller
 * 
 * @author ruoyi
 * @date 2021-12-29
 */
@Controller
@RequestMapping("/system/nav")
public class NavInfoController extends BaseController
{
    private String prefix = "system/nav";

    @Autowired
    private INavInfoService navInfoService;

    @RequiresPermissions("system:nav:view")
    @GetMapping()
    public String nav()
    {
        return prefix + "/nav";
    }

    /**
     * 查询中关村导航管理树列表
     */
    @RequiresPermissions("system:nav:list")
    @PostMapping("/list")
    @ResponseBody
    public List<NavInfo> list(NavInfo navInfo)
    {
        List<NavInfo> list = navInfoService.selectNavInfoList(navInfo);
        return list;
    }

    /**
     * 导出中关村导航管理列表
     */
    @RequiresPermissions("system:nav:export")
    @Log(title = "中关村导航管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ResponseBody
    public AjaxResult export(NavInfo navInfo)
    {
        List<NavInfo> list = navInfoService.selectNavInfoList(navInfo);
        ExcelUtil<NavInfo> util = new ExcelUtil<NavInfo>(NavInfo.class);
        return util.exportExcel(list, "中关村导航管理数据");
    }

    /**
     * 新增中关村导航管理
     */
    @GetMapping(value = { "/add/{navId}", "/add/" })
    public String add(@PathVariable(value = "navId", required = false) Long navId, ModelMap mmap)
    {
        if (StringUtils.isNotNull(navId))
        {
            mmap.put("navInfo", navInfoService.selectNavInfoByNavId(navId));
        }
        return prefix + "/add";
    }

    /**
     * 新增保存中关村导航管理
     */
    @RequiresPermissions("system:nav:add")
    @Log(title = "中关村导航管理", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    @ResponseBody
    public AjaxResult addSave(NavInfo navInfo)
    {
        return toAjax(navInfoService.insertNavInfo(navInfo));
    }

    /**
     * 修改中关村导航管理
     */
    @RequiresPermissions("system:nav:edit")
    @GetMapping("/edit/{navId}")
    public String edit(@PathVariable("navId") Long navId, ModelMap mmap)
    {
        NavInfo navInfo = navInfoService.selectNavInfoByNavId(navId);
        mmap.put("navInfo", navInfo);
        return prefix + "/edit";
    }

    /**
     * 修改保存中关村导航管理
     */
    @RequiresPermissions("system:nav:edit")
    @Log(title = "中关村导航管理", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    @ResponseBody
    public AjaxResult editSave(NavInfo navInfo)
    {
        return toAjax(navInfoService.updateNavInfo(navInfo));
    }

    /**
     * 删除
     */
    @RequiresPermissions("system:nav:remove")
    @Log(title = "中关村导航管理", businessType = BusinessType.DELETE)
    @GetMapping("/remove/{navId}")
    @ResponseBody
    public AjaxResult remove(@PathVariable("navId") Long navId)
    {
        return toAjax(navInfoService.deleteNavInfoByNavId(navId));
    }

    /**
     * 选择中关村导航管理树
     */
    @GetMapping(value = { "/selectNavTree/{navId}", "/selectNavTree/" })
    public String selectNavTree(@PathVariable(value = "navId", required = false) Long navId, ModelMap mmap)
    {
        if (StringUtils.isNotNull(navId))
        {
            mmap.put("navInfo", navInfoService.selectNavInfoByNavId(navId));
        }
        return prefix + "/tree";
    }

    /**
     * 加载中关村导航管理树列表
     */
    @GetMapping("/treeData")
    @ResponseBody
    public List<Ztree> treeData()
    {
        List<Ztree> ztrees = navInfoService.selectNavInfoTree();
        return ztrees;
    }
}
